# pypeln
`pypeln` is a python library that lets you easily create concurrent data pipelines in a functional style. 


## Contributors
* [cgarciae](https://github.com/cgarciae)
* [davidnet](https://github.com/davidnet)